@@ -1,9 +1,21 @@
-/* 
- * getopt entry points
+/** @file getopt.cc
+\brief getopt entry points */
+/*
+ * Copyright (C) 2000, 2006, 2007
+ * Michael S. Borella <mike@borella.net> and
  *
- * modified by Mike Borella <mike_borella@mw.3com.com>
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * $Id: getopt.cc,v 1.3 2000/10/25 22:52:05 mborella Exp $
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -163,7 +175,7 @@ getopt (int argc, char * const * argv, const char * optstring)
 #if defined (WIN32) && !defined (__CYGWIN32__)
 /* It's not Unix, really.  See?  Capital letters.  */
 #include <windows.h>
-#define getpid() GetCurrentProcessId()
+#define getpid () GetCurrentProcessId ()
 #endif
 
 #ifndef _
@@ -291,7 +303,7 @@ static char *posixly_correct;
 /* Avoid depending on library functions or files
    whose names are inconsistent.  */
 
-extern char * getenv(const char *);
+extern char * getenv (const char *);
 
 static char *
 my_index (const char *str, int chr)
@@ -357,7 +369,7 @@ store_args_and_env (int argc, char *const *argv)
 }
 text_set_element (__libc_subinit, store_args_and_env);
 
-# define SWAP_FLAGS(ch1, ch2) \
+# define SWAP_FLAGS (ch1, ch2) \
   if (nonoption_flags_len > 0)						      \
     {									      \
       char __tmp = __getopt_nonoption_flags[ch1];			      \
@@ -365,7 +377,7 @@ text_set_element (__libc_subinit, store_args_and_env);
       __getopt_nonoption_flags[ch2] = __tmp;				      \
     }
 #else	/* !_LIBC */
-# define SWAP_FLAGS(ch1, ch2)
+# define SWAP_FLAGS (ch1, ch2)
 #endif	/* _LIBC */
 
 /* Exchange two adjacent subsequences of ARGV.
